=========================
``cavcalc.output.Output``
=========================

.. currentmodule:: cavcalc.output

Overview
========

.. autoclass:: Output

Properties
==========

.. autosummary::
    :toctree: generated/

    Output.computed

Methods
=======

.. autosummary::
    :toctree: generated/

	Output.__init__
    Output.print
	Output.get
	Output.constant_dependents
	Output.arraylike_dependents
	Output.constant_results
	Output.vector_results
	Output.grid_results
	Output.plot
	Output.implot
